@@ -5,6 +5,8 @@
 #include "admin/adminaccountinfo.h"
 
 #include <KLocalizedString>
+#include <QJsonDocument>
+#include <QNetworkReply>
 
 #include "account/abstractaccount.h"
 #include "account/accountmanager.h"
@@ -235,4 +237,4 @@ void AdminAccountInfo::calculateRecentActivity(const QJsonArray &ipsArray)
     m_lastActive = latestDateTime.toLocalTime();
 }
 
-#include "moc_adminaccountinfo.cpp"
\ No newline at end of file
+#include "moc_adminaccountinfo.cpp"
