@@ -169,15 +169,13 @@ void ReportInfo::fromSourceData(const QJsonObject &doc)
     m_assignedModerator = !m_assignedAccount->userLevelIdentity()->account().isEmpty();
     // creating status array with the Post class
     const auto reportStatuses = doc[QStringLiteral("statuses")].toArray();
-    std::transform(
-        reportStatuses.cbegin(),
-        reportStatuses.cend(),
-        std::back_inserter(m_reportStatus),
-        [ this, account ](const QJsonValue &value) -> auto{ return new Post(account, value.toObject(), this); });
+    std::ranges::transform(std::as_const(reportStatuses), std::back_inserter(m_reportStatus), [this, account](const QJsonValue &value) -> auto {
+        return new Post(account, value.toObject(), this);
+    });
 
     m_rules = doc["rules"_L1].toArray();
 
     Q_EMIT reportInfoUpdated();
 }
 
-#include "moc_reportinfo.cpp"
\ No newline at end of file
+#include "moc_reportinfo.cpp"
