@@ -249,7 +249,7 @@ QJsonDocument PostEditorBackend::toJsonDocument() const
     }
 
     if (m_scheduledAt.isValid()) {
-        obj["scheduled_at"_L1] = m_scheduledAt.toString(Qt::DateFormat::ISODate);
+        obj["scheduled_at"_L1] = m_scheduledAt.toUTC().toString(Qt::DateFormat::ISODate);
     }
 
     return QJsonDocument(obj);
@@ -257,6 +257,11 @@ QJsonDocument PostEditorBackend::toJsonDocument() const
 
 void PostEditorBackend::save()
 {
+    // If we were editing a scheduled or draft post, make sure to clean up the previous iteration
+    if (!m_scheduledPostId.isEmpty()) {
+        m_account->deleteResource(m_account->apiUrl(QStringLiteral("/api/v1/scheduled_statuses/%1").arg(m_scheduledPostId)), true, this, {});
+    }
+
     QUrl post_status_url = m_account->apiUrl(QStringLiteral("/api/v1/statuses"));
     auto doc = toJsonDocument();
 
@@ -268,10 +273,10 @@ void PostEditorBackend::save()
         doc,
         true,
         this,
-        [=](QNetworkReply *) {
+        [this](QNetworkReply *) {
             Q_EMIT posted(QStringLiteral(""));
         },
-        [=](QNetworkReply *reply) {
+        [this](QNetworkReply *reply) {
             auto data = reply->readAll();
             auto doc = QJsonDocument::fromJson(data);
             auto obj = doc.object();
@@ -290,7 +295,7 @@ void PostEditorBackend::edit()
     QUrl edit_status_url = m_account->apiUrl(QStringLiteral("/api/v1/statuses/%1").arg(m_id));
     auto doc = toJsonDocument();
 
-    m_account->put(edit_status_url, doc, true, this, [=](QNetworkReply *reply) {
+    m_account->put(edit_status_url, doc, true, this, [this](QNetworkReply *reply) {
         auto data = reply->readAll();
         auto doc = QJsonDocument::fromJson(data);
         auto obj = doc.object();
@@ -299,4 +304,57 @@ void PostEditorBackend::edit()
     });
 }
 
+void PostEditorBackend::saveDraft()
+{
+    // Set it far in the future so it's a "draft"
+    auto currentDate = QDateTime::currentDateTime();
+    currentDate = currentDate.addYears(3000);
+    setScheduledAt(currentDate);
+
+    save();
+}
+
+void PostEditorBackend::loadScheduledPost(const QString &id)
+{
+    QUrl url = m_account->apiUrl(QStringLiteral("/api/v1/scheduled_statuses/%1").arg(id));
+
+    m_account->get(url, true, this, [this, id](QNetworkReply *reply) {
+        auto data = reply->readAll();
+        auto doc = QJsonDocument::fromJson(data);
+        auto obj = doc.object();
+
+        auto params = obj["params"_L1].toObject();
+        if (params["poll"_L1].isObject()) {
+            auto poll = params["poll"_L1].toObject();
+            auto options = poll["options"_L1].toArray();
+            m_poll->clearOptions();
+            // FIXME: everything but the last poll option is restored, due to limitations in how the poll composer is designed
+            for (int i = 0; i < options.size(); ++i) {
+                m_poll->addOption();
+                m_poll->setOption(i, options[i].toString());
+            }
+            m_poll->setExpiresIn(poll["expires_in"_L1].toInt());
+            m_poll->setMultipleChoice(poll["multiple"_L1].toBool());
+            m_poll->setHideTotals(poll["hide_totals"_L1].toBool());
+            m_pollEnabled = true;
+        } else {
+            m_pollEnabled = false;
+        }
+        Q_EMIT pollEnabledChanged();
+        setStatus(params["text"_L1].toString());
+        setLanguage(params["language"_L1].toString());
+        m_attachmentEditorModel->copyFromArray(obj["media_attachments"_L1].toArray());
+        setSensitive(params["sensitive"_L1].toBool());
+        setScheduledAt(QDateTime::fromString(params["scheduled_at"_L1].toString(), Qt::ISODate));
+        setSpoilerText(params["spoiler_text"_L1].toString());
+        setInReplyTo(params["in_reply_to"_L1].toString());
+        setVisibility(Post::stringToVisibility(params["visibility"_L1].toString()));
+
+        // Save this id for later, so we clean up the draft once we properly posted it.
+        m_scheduledPostId = id;
+
+        Q_EMIT scheduledPostLoaded();
+    });
+}
+
 #include "moc_posteditorbackend.cpp"
