@@ -16,6 +16,7 @@ class NotificationGroupingModel : public QAbstractProxyModel
 
     Q_PROPERTY(bool loading READ loading NOTIFY loadingChanged)
     Q_PROPERTY(NotificationModel *sourceModel WRITE setSourceModel READ getSourceModel NOTIFY sourceModelChanged)
+    Q_PROPERTY(bool fullyRead READ fullyRead NOTIFY readMarkerChanged)
 
 public:
     explicit NotificationGroupingModel(QObject *parent = nullptr);
@@ -41,6 +42,8 @@ public:
 
     Q_INVOKABLE void markAllNotificationsAsRead();
 
+    bool fullyRead() const;
+
 public Q_SLOTS:
     /**
      * @brief Reply to the notification at @p index.
@@ -82,6 +85,7 @@ public Q_SLOTS:
 Q_SIGNALS:
     void loadingChanged();
     void sourceModelChanged();
+    void readMarkerChanged();
 
 private:
     bool notificationsMatch(const QModelIndex &a, const QModelIndex &b);
